"use strict";

var Queue = require('promise-queue');

var fs = require('fs-extra');

var path = require('path');

var md5 = require('md5');

var request = require('request-promise-native');

var resizeUrl = require('./resizeUrl');

var queryString = require('query-string');

var queue = new Queue(3, Infinity);

function download(requestUrl, cacheDir) {
  var cacheFile = path.join(cacheDir, md5(requestUrl));

  if (fs.existsSync(cacheFile)) {
    var body = fs.readFileSync(cacheFile, 'utf8');
    return Promise.resolve(body);
  }

  return queue.add(function () {
    return request({
      uri: encodeURI(requestUrl),
      resolveWithFullResponse: true,
      encoding: 'base64'
    }).then(function (res) {
      var data = 'data:' + res.headers['content-type'] + ';base64,' + res.body;
      fs.writeFileSync(cacheFile, data, 'utf8');
      return data;
    });
  });
}

module.exports = function (_ref, apiToken, cacheDir) {
  var image = _ref.image,
      src = _ref.src,
      width = _ref.width,
      height = _ref.height,
      aspectRatio = _ref.aspectRatio;
  var imgixParams = queryString.parse(src.split('?')[1]);
  imgixParams['auth_token'] = apiToken;
  return download("https://site-api.datocms.com/uploads/".concat(image.originalId, "/lqip?").concat(queryString.stringify(imgixParams)), cacheDir);
};